@@ -6,16 +6,15 @@ from collections.abc import Callable
 from dataclasses import dataclass
 from enum import Enum
 import logging
-from typing import Any
-from typing import final
-from typing import Protocol
-from typing import TypedDict
+from typing import Any, Protocol, TypedDict, final
 
 import aiohttp
-from pyalarmdotcomajax.errors import InvalidConfigurationOption
-from pyalarmdotcomajax.errors import UnexpectedDataStructure
-from pyalarmdotcomajax.extensions import CameraSkybellControllerExtension
-from pyalarmdotcomajax.extensions import ConfigurationOption
+
+from pyalarmdotcomajax.errors import InvalidConfigurationOption, UnexpectedDataStructure
+from pyalarmdotcomajax.extensions import (
+    CameraSkybellControllerExtension,
+    ConfigurationOption,
+)
 from pyalarmdotcomajax.helpers import ExtendedEnumMixin
 
 log = logging.getLogger(__name__)
@@ -35,6 +34,7 @@ class DeviceType(ExtendedEnumMixin):
 
     # Supported
     GARAGE_DOOR = "garageDoors"
+    GATE = "gates"
     IMAGE_SENSOR = "imageSensors"
     LIGHT = "lights"
     LOCK = "locks"
@@ -42,6 +42,7 @@ class DeviceType(ExtendedEnumMixin):
     SENSOR = "sensors"
     SYSTEM = "systems"
     THERMOSTAT = "thermostats"
+    WATER_SENSOR = "waterSensors"
 
     # Unsupported
     ACCESS_CONTROL = "accessControlAccessPointDevices"
@@ -51,7 +52,6 @@ class DeviceType(ExtendedEnumMixin):
     COMMERCIAL_TEMP = "commercialTemperatureSensors"
     # CONFIGURATION = "configuration"
     # FENCE = "fences"
-    GATE = "gates"
     GEO_DEVICE = "geoDevices"
     IQ_ROUTER = "iqRouters"
     REMOTE_TEMP = "remoteTemperatureSensors"
@@ -62,7 +62,6 @@ class DeviceType(ExtendedEnumMixin):
     SWITCH = "switches"
     VALVE_SWITCH = "valveSwitches"
     WATER_METER = "waterMeters"
-    WATER_SENSOR = "waterSensors"
     WATER_VALVE = "waterValves"
     X10_LIGHT = "x10Lights"
 
@@ -77,6 +76,10 @@ DEVICE_URLS: dict = {
             "relationshipId": "devices/garage-door",
             "endpoint": "{}web/api/devices/garageDoors/{}",
         },
+        DeviceType.GATE: {
+            "relationshipId": "devices/gate",
+            "endpoint": "{}web/api/devices/gates/{}",
+        },
         DeviceType.IMAGE_SENSOR: {
             "relationshipId": "image-sensor/image-sensor",
             "endpoint": "{}web/api/imageSensor/imageSensors/{}",
@@ -110,6 +113,10 @@ DEVICE_URLS: dict = {
             "relationshipId": "devices/thermostat",
             "endpoint": "{}web/api/devices/thermostats/{}",
         },
+        DeviceType.WATER_SENSOR: {
+            "relationshipId": "devices/water-sensor",
+            "endpoint": "{}web/api/devices/waterSensors/{}",
+        },
     },
     "unsupported": {
         DeviceType.ACCESS_CONTROL: {
@@ -136,10 +143,6 @@ DEVICE_URLS: dict = {
         #     "relationshipId": "",
         #     "endpoint": "{}web/api/geolocation/fences/{}",
         # },
-        DeviceType.GATE: {
-            "relationshipId": "devices/gate",
-            "endpoint": "{}web/api/devices/gates/{}",
-        },
         DeviceType.GEO_DEVICE: {
             "relationshipId": "geolocation/geo-device",
             "endpoint": "{}web/api/geolocation/geoDevices/{}",
@@ -180,10 +183,6 @@ DEVICE_URLS: dict = {
             "relationshipId": "devices/water-meter",
             "endpoint": "{}web/api/devices/waterMeters/{}",
         },
-        DeviceType.WATER_SENSOR: {
-            "relationshipId": "devices/water-sensor",
-            "endpoint": "{}web/api/devices/waterSensors/{}",
-        },
         DeviceType.WATER_VALVE: {
             "relationshipId": "devices/water-valve",
             "endpoint": "{}web/api/devices/waterValves/{}",
@@ -315,7 +314,7 @@ class BaseDevice:
 
     @final
     def _get_list(self, key: str, value_type: type) -> list | None:
-        """Cast raw value to bool. Satisfies mypy."""
+        """Cast raw value to list. Satisfies mypy."""
 
         try:
             duration_list: list = list(self._attribs_raw.get(key))  # type: ignore
@@ -481,7 +480,7 @@ class BaseDevice:
     def desired_state(self) -> Enum | None:
         """Return state. To be overridden by children."""
 
-    def process_element_specific_data(self) -> None:  # pylint: disable=no-self-use
+    def process_element_specific_data(self) -> None:
         """Process element specific data. To be overridden by children."""
 
         return None
@@ -491,8 +490,10 @@ class BaseDevice:
 
         if not self._config_change_callback:
             log.error(
-                "async_change_setting called for %s, which does not have a"
-                " config_change_callback set.",
+                (
+                    "async_change_setting called for %s, which does not have a"
+                    " config_change_callback set."
+                ),
                 self.name,
             )
             return
@@ -506,8 +507,10 @@ class BaseDevice:
             raise InvalidConfigurationOption
 
         log.debug(
-            "BaseDevice -> async_change_setting: Calling change setting function for %s"
-            " %s (%s) via extension %s.",
+            (
+                "BaseDevice -> async_change_setting: Calling change setting function"
+                " for %s %s (%s) via extension %s."
+            ),
             type(self).__name__,
             self.name,
             self.id_,
